Skip to contents

This function checks for common issues in a Quarto website project directory. Currently, it finds:

  • Subfolders lacking index.qmd

  • .qmd files without a title in their YAML front matter Future versions will add more checks.

Usage

detect_malformed_quarto_project(root_dir)

Arguments

root_dir

Path to the root directory of the Quarto website project.

Value

A data.frame with columns: type, path, details

Examples

detect_malformed_quarto_project(tempdir())
#>                type                                                   path
#> 1 missing_index.qmd                                        /tmp/RtmpBTNcfC
#> 2 missing_index.qmd /tmp/RtmpBTNcfC/bslib-d3693434e0b34834558e37e4bcb7498f
#> 3 missing_index.qmd                                /tmp/RtmpBTNcfC/downlit
#>                     details
#> 1 No index.qmd in subfolder
#> 2 No index.qmd in subfolder
#> 3 No index.qmd in subfolder