Detect malformed Quarto website projects generated by saros.base
Source:R/detect_malformed_quarto_project.R
detect_malformed_quarto_project.RdThis function checks for common issues in a Quarto website project directory. Currently, it finds:
Subfolders lacking index.qmd
.qmd files without a title in their YAML front matter Future versions will add more checks.
Examples
detect_malformed_quarto_project(tempdir())
#> type path
#> 1 missing_index.qmd /tmp/RtmpBTNcfC
#> 2 missing_index.qmd /tmp/RtmpBTNcfC/bslib-d3693434e0b34834558e37e4bcb7498f
#> 3 missing_index.qmd /tmp/RtmpBTNcfC/downlit
#> details
#> 1 No index.qmd in subfolder
#> 2 No index.qmd in subfolder
#> 3 No index.qmd in subfolder